@@ -19,7 +19,7 @@
  ***************************************************************************/
 
 
-// #define _DEBUG
+#define _DEBUG
 #include "kndiswrapper.h"
 #include <icons.h>
 
@@ -29,10 +29,9 @@
 kndiswrapper::kndiswrapper() : QWidget( 0, "kndiswrapper" )
 {
 
+
     QString homePath=getenv("HOME");
     int rc;
-    QString text = "dies ist ein Test \
-    ob man Text auch über mehrere Zeilen kann";
 
     QString commentText = tr("KNDISWrapper will help you to setup your wireless network with ndiswrapper.\n\nThe Install Driver Button \
 is used to install a new driver for a wireless dvice supported by ndiswrapper. To do so, you have to \
@@ -57,14 +56,21 @@ With the Quit Button you exit this application.");
     hwList=32;
     netconf=64;
 
+    disablerootcheck=false;
+    disablenetconf=false;
+    invokeSetup=false;
+  if (qApp->argc() > 1){
+    for (int i=0; i < qApp->argc();i++){
+      if ((QString)qApp->argv()[i] == "--disablerootcheck") disablerootcheck=true;
+      if ((QString)qApp->argv()[i] == "--setup") invokeSetup=true;
+      if ((QString)qApp->argv()[i] == "--disablenetconf") disablenetconf=true;
+    }
+  }
+
     if (QFile::exists(homePath + "/.kndiswrapper") == false){
         rc = system("mkdir " + homePath + "/.kndiswrapper");
     }
 
-    if (QFile::exists(homePath + "/.kndiswrapper/translations") == false){
-        rc = system("mkdir " + homePath + "/.kndiswrapper/translations");
-    }
-
     this->setFixedSize(700,340);
 
     comment = new QMultiLineEdit(this,"comment");
@@ -80,8 +86,12 @@ With the Quit Button you exit this application.");
     contextMenu->insertSeparator();
     contextMenu->insertItem(QPixmap(kndiswrapper_xpm),tr("Module Check"),this,SLOT(slot_moduleCheckRequested()));
     contextMenu->insertItem(QPixmap(info_xpm),tr("Info dmesg"),this,SLOT(slot_infoProcessRequested()));
-    contextMenu->insertSeparator();
-    contextMenu->insertItem(QPixmap(confignetwork_xpm),tr("Config Network"),this,SLOT(slot_configNetworkRequested()));
+    contextMenu->insertItem(QPixmap(wiki_xpm),tr("Offline Wiki"),this,SLOT(slot_wikiRequested()));
+
+    if (!disablenetconf){
+      contextMenu->insertSeparator();
+      contextMenu->insertItem(QPixmap(confignetwork_xpm),tr("Config Network"),this,SLOT(slot_configNetworkRequested()));
+    }
 
     hardwareList = new QTable(0,1,this,"hardwareList");
     hardwareList->setTopMargin(2);
@@ -93,27 +103,29 @@ With the Quit Button you exit this application.");
     logoLabel->setPixmap(QPixmap(kndiswrapper_logo_xpm));
 
     addDriverButton = new QPushButton(QPixmap(adddriver_xpm),tr("Install Driver"),this,"addDriverButton");
-    addDriverButton->setFont(QFont("Helvetic",12,QFont::Normal,false));
+    addDriverButton->setFont(QFont("Helvetic",10,QFont::Normal,false));
     QToolTip::add(addDriverButton,tr("Install a new driver. Therefor locate the appropriate .inf file."));
 
     removeDriverButton = new QPushButton(QPixmap(deldriver_xpm),tr("Remove Driver"),this,"removeDriverButton");
-    removeDriverButton->setFont(QFont("Helvetic",12,QFont::Normal,false));
+    removeDriverButton->setFont(QFont("Helvetic",10,QFont::Normal,false));
     QToolTip::add(removeDriverButton,tr("Removes the selected driver in the list."));
 
     reloadButton = new QPushButton(QPixmap(reload_xpm),tr("Reload List"),this,"reloadButton");
-    reloadButton->setFont(QFont("Helvetic",12,QFont::Normal,false));
+    reloadButton->setFont(QFont("Helvetic",10,QFont::Normal,false));
     QToolTip::add(reloadButton,tr("Reload the content of the list"));
 
     restoreDriverButton = new QPushButton(QPixmap(restore_xpm),tr("Restore Driver"),this,"restoreDriverButton");
-    restoreDriverButton->setFont(QFont("Helvetic",12,QFont::Normal,false));
+    restoreDriverButton->setFont(QFont("Helvetic",10,QFont::Normal,false));
     QToolTip::add(restoreDriverButton,tr("Restores a removed driver."));
 
-    configNetworkButton = new QPushButton(QPixmap(confignetwork_xpm),tr("Config Network"),this,"configNetworkButton");
-    configNetworkButton->setFont(QFont("Helvetic",12,QFont::Normal,false));
-    QToolTip::add(configNetworkButton,tr("Start's the network configuration dialog"));
+    if (!disablenetconf){
+      configNetworkButton = new QPushButton(QPixmap(confignetwork_xpm),tr("Config Network"),this,"configNetworkButton");
+      configNetworkButton->setFont(QFont("Helvetic",10,QFont::Normal,false));
+      QToolTip::add(configNetworkButton,tr("Start's the network configuration dialog"));
+    }
 
     quitButton = new QPushButton(QPixmap(stop_xpm),tr("Quit"),this,"quitButton");
-    quitButton->setFont(QFont("Helvetic",12,QFont::Normal,false));
+    quitButton->setFont(QFont("Helvetic",10,QFont::Normal,false));
     QToolTip::add(quitButton,tr("Quit the application"));
 
     getConfProcess = new QProcess(this);
@@ -140,7 +152,7 @@ With the Quit Button you exit this application.");
     connect(moduleLoadedCheckProcess,SIGNAL(processExited()),this,SLOT(slot_moduleLoadedCheckProcessExited()));
     connect(infoProcess,SIGNAL(processExited()),this,SLOT(slot_infoProcessExited()));
     connect(configNetworkProcess,SIGNAL(processExited()),this,SLOT(slot_configNetworkProcessExited()));
-    connect(configNetworkButton,SIGNAL(clicked()),this,SLOT(slot_configNetworkRequested()));
+    if (!disablenetconf) connect(configNetworkButton,SIGNAL(clicked()),this,SLOT(slot_configNetworkRequested()));
 
     activateControls(addDriver|delDriver|reloadList|restoreDriver|quit|hwList|netconf);
     moveButtonTimer = new QTimer(this);
@@ -154,16 +166,33 @@ kndiswrapper::~kndiswrapper()
 {
 }
 
+
 void kndiswrapper::initWidget(){
-#ifndef _DEBUG
-    if ((QString)getenv("HOME") != "/root"){
-        QProcess launcher;
-        launcher.addArgument("kdesu");
-        launcher.addArgument("kndiswrapper");
-        launcher.start();
-        exit(0);
+    if (invokeSetup){
+      QProcess launcher;
+      launcher.addArgument("kdesu");
+      launcher.addArgument("kndiswrapper");
+      launcher.addArgument("--setup");
+      launcher.start();
+      exit(0);
     }
-#endif
+
+    if (!disablerootcheck){
+      if ((QString)getenv("HOME") != "/root"){
+        QString launcher;
+        launcher = "kdesu ";
+        launcher = launcher + "\"kndiswrapper ";
+        if (qApp->argc() > 1){
+          for (int i=1; i < qApp->argc();i++){
+            launcher = launcher + (QString)qApp->argv()[i] + " ";
+          }
+        }
+        launcher = launcher + "\" &";
+        system(launcher);
+        exit(0);
+      }
+    }
+
     findNDISProcess->addArgument("whereis");
     findNDISProcess->addArgument("ndiswrapper");
     findNDISProcess->start();
@@ -188,7 +217,7 @@ void kndiswrapper::resizeEvent(QResizeEvent * e){
     reloadButton->setGeometry(hardwareList->x()+hardwareList->width()+5,hardwareList->y(),this->width()-hardwareList->width()-265,40);
     restoreDriverButton->setGeometry(hardwareList->x()+hardwareList->width()+5,hardwareList->y(),this->width()-hardwareList->width()-265,40);
     quitButton->setGeometry(hardwareList->x()+hardwareList->width()+5,hardwareList->y(),this->width()-hardwareList->width()-265,40);
-    configNetworkButton->setGeometry(hardwareList->x()+hardwareList->width()+5,hardwareList->y(),this->width()-hardwareList->width()-265,40);
+    if (!disablenetconf) configNetworkButton->setGeometry(hardwareList->x()+hardwareList->width()+5,hardwareList->y(),this->width()-hardwareList->width()-265,40);
 }
 
 void kndiswrapper::getConf(){
@@ -335,17 +364,37 @@ void kndiswrapper::slot_restoreDriverButtonClicked(){
 }
 
 void kndiswrapper::slot_addDriverButtonClicked(){
-    QString homePath=(QString)getenv("HOME");
-    QString rc;
+QString homePath=(QString)getenv("HOME");
+QString rc;
+QString driver;
+int rc2;
+int rc3;
+wikiLookup * hardwareInfo;
+instWizard * wizard;
 
-    rc = QFileDialog::getOpenFileName(homePath,tr("INF-Files (*.inf)"),this,tr("New Driver"),tr("Select a File"));
-    if (rc != ""){
-        activateControls(disabled);
-        restoreProcess->clearArguments();
-        restoreProcess->addArgument(ndiswrapperPath);
-        restoreProcess->addArgument("-i");
-        restoreProcess->addArgument(rc);
-        restoreProcess->start();
+    rc2 = QMessageBox::question(this,"Hardware Info",tr("Do you want to use the installation wizard or do you want to select the appropirate *.inf file by yourself"),"Start Wizard","Manual Inst.","Abort Inst.");
+    switch(rc2){
+    case 0 : wizard = new instWizard(this,"wizard",&driver);
+             rc3 = wizard->exec();
+             if (rc3 == QDialog::Accepted) {
+               activateControls(disabled);
+               restoreProcess->clearArguments();
+               restoreProcess->addArgument(ndiswrapperPath);
+               restoreProcess->addArgument("-i");
+               restoreProcess->addArgument(driver);
+               restoreProcess->start();
+             }
+                break;
+    case 1 : rc = QFileDialog::getOpenFileName(homePath,tr("INF-Files (*.inf)"),this,tr("New Driver"),tr("Select a File"));
+             if (rc != ""){
+               activateControls(disabled);
+               restoreProcess->clearArguments();
+               restoreProcess->addArgument(ndiswrapperPath);
+               restoreProcess->addArgument("-i");
+               restoreProcess->addArgument(rc);
+               restoreProcess->start();
+             }
+                break;
     }
 }
 
@@ -474,7 +523,7 @@ void kndiswrapper::activateControls(int state){
     (state & restoreDriver) == restoreDriver?restoreDriverButton->setEnabled(true):restoreDriverButton->setEnabled(false);
     (state & quit) == quit?quitButton->setEnabled(true):quitButton->setEnabled(false);
     (state & hwList) == hwList?hardwareList->setEnabled(true):hardwareList->setEnabled(false);
-    (state & netconf) == netconf?configNetworkButton->setEnabled(true):configNetworkButton->setEnabled(false);
+    if (!disablenetconf) (state & netconf) == netconf?configNetworkButton->setEnabled(true):configNetworkButton->setEnabled(false);
 }
 
 void kndiswrapper::slot_moduleLoadedCheckProcessExited(){
@@ -629,10 +678,12 @@ int x;
         restoreDriverButton->move(x,y);
       }
 
-      y = configNetworkButton->y();
-      if (configNetworkButtonEndPosition > y){
-        y+=4;
-        configNetworkButton->move(x,y);
+      if (!disablenetconf){
+        y = configNetworkButton->y();
+        if (configNetworkButtonEndPosition > y){
+          y+=4;
+          configNetworkButton->move(x,y);
+        }
       }
 
       y = quitButton->y();
@@ -645,4 +696,12 @@ int x;
     moveButtonTimer->start(6,true);
   }
 }
+
+void kndiswrapper::slot_wikiRequested(){
+wikiLookup * hardwareInfo;
+
+    hardwareInfo = new wikiLookup(this,"hardwareInfo",1);
+    hardwareInfo->exec();
+}
+
 #include "kndiswrapper.moc"
